shape ops work in progress

git-svn-id: http://skia.googlecode.com/svn/trunk@6223 2bbb7eff-a529-9590-31e7-b0007b416f81
diff --git a/experimental/Intersection/EdgeDemoApp.mm b/experimental/Intersection/EdgeDemoApp.mm
index 67dc613..41dea67 100644
--- a/experimental/Intersection/EdgeDemoApp.mm
+++ b/experimental/Intersection/EdgeDemoApp.mm
@@ -12,12 +12,12 @@
     SkSampleView() {
         this->setVisibleP(true);
         this->setClipToBounds(false);
-        useOld = true;
+        useOld = false;
     };
 protected:
     virtual void onDraw(SkCanvas* canvas) {
-        static int step = 9658; // 17909 ; // drawLetters first error
-                             // drawStars triggers error at 23275
+        static int step = 17907; // 17907 drawLetters first error
+                             // drawStars triggers error at 33348
                              // drawStars error not easy to debug last time I checked
         static double seconds;
         if (step == -1) {
@@ -29,7 +29,7 @@
         canvas->drawColor(SK_ColorWHITE);
         if (DrawEdgeDemo(canvas, step, useOld)) {
             ++step;
-            if (step == 23270) {
+            if (step == -1) {
                 timeval t;
                 gettimeofday(&t, NULL);
                 double last = seconds;